@@ -14,18 +14,11 @@ distances <- matrix(NA, ncol(data), numGroups)
 for(j in 1:numGroups)
 distances[,j] <- apply(data, 2, function(x){calcDistance(x, mixture$gstars[[j]], type)})
 
-#Calculate the weighted loglikelihood values
-LL <- 0
-for(i in 1:numGraphs){
-tempLL <- 0
-for(j in 1:numGroups){
-tau <- mixture$taus[j]
-weight <- mixture$weights[j]
-tempLL <- tempLL + weight * (1+exp(-tau))^(-edges) * exp(-tau*distances[i, j]) 
+t <- matrix(NA, ncol(data), numGroups)
+for(i in 1:numGraphs)
+t[i,] <- log(mixture$weights) - edges*log((1+exp(-mixture$taus))) - mixture$taus*distances[i,]
 
-}
-LL <- LL + log(tempLL)
-}
+LL <- sum(apply(t, 1, logSumExp))
 
 BIC <- -2*LL + numGroups * (2+edges) * log(numGraphs)
 
